goto_question_mark_conversions

Function goto_question_mark_conversions 

fn goto_question_mark_conversions(
    sema: &Semantics<'_, RootDatabase>,
    node: &SyntaxNode,
) -> Option<Function>
When the ? operator is used on Result, go to the From impl if it exists as this provides more value.